<li class="item"{% if image %} style="background-image:url({{ image.url }});"{% endif %}>
    {% if instance.content %}
    <div class="item-content">
        {{ instance.content|safe }}
    </div>
    {% endif %}
</li>